==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicToolBarUI__24ToolBarBorder.h <==
// class javax.swing.plaf.basic.BasicToolBarUI$ToolBarBorder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6db52325e2a360c3 javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder_H_
#define _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object;

typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$fields_struct	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vmethods	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtable	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtype	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$fields_struct {
	jint	offset;
	jint	regular;
};
extern _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$fields_struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *);
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method$_init$59ddfe61f422edf6(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__241$object *);

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *, struct _jc_java_awt_Component$object *);
extern jboolean _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *);
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method$paintBumps$63b03c1893dda44a(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint, jint, struct _jc_java_awt_Color$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method_info$paintBorder$4a79b2eae89db578;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method_info$paintBumps$63b03c1893dda44a;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *, struct _jc_java_awt_Component$object *);
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *);
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
	void	(*paintBumps$63b03c1893dda44a)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint, jint, struct _jc_java_awt_Color$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vmethods	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$refs {
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$sub_refs	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$sub_nonrefs	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object {
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtype _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicToolBarUI__24ToolBarBorder.h <==
// class javax.swing.plaf.basic.BasicToolBarUI$ToolBarBorder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 815aeda4a8141488 javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder_H_
#define _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object;

typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$fields_struct	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vmethods	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtable	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtype	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$fields_struct {
	jint	offset;
	jint	regular;
};
extern _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$fields_struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method$_init$59ddfe61f422edf6(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method$paintBumps$63b03c1893dda44a(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint, jint, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method_info$paintBorder$4a79b2eae89db578;
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$method_info$paintBumps$63b03c1893dda44a;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *) _JC_JCNI_ATTR;
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
	void	(*paintBumps$63b03c1893dda44a)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint, jint, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vmethods	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$refs {
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$sub_refs	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$sub_nonrefs	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$object {
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$vtype _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarBorder_H_ */
